==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/ru.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Ссылка:",
    "Password:" : "Пароль:",
    "Generating system report failed." : "Не удалось создать отчёт о системе.",
    "Subscription notifications" : "Уведомление о подписке",
    "Could not create folder \"System information\" to store generated report." : "Не удалось создать папку «System information» для сохранения отчёта.",
    "Could not create file \"%s\" to store generated report." : "Не удалось создать файл «%s» для сохранения отчёта.",
    "Could not share file \"%s\"." : "Не удалось предоставить общий доступ к файлу «%s».",
    "Nextcloud Subscription" : "Подписка Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "У вашего сервера нет подписки Nextcloud или ваша подписка истекла.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ваша подписка на сервер Nextcloud не распространяется на количество пользователей Вашего сервера.",
    "Your Nextcloud Subscription has expired!" : "Закончился срок действия подписки Nextcloud!",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Ваш сервер Nextcloud не поддерживается подпиской Nextcloud Enterprise.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Подписка на поддержку Nextcloud означает, что оригинальные разработчики вашего частного облачного сервера на 100% посвятили вашему успеху: безопасности, масштабируемости, производительности и функциональности вашего сервиса!",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Если у вас возникла проблема, и ваш сервер больше не работает, блокируя сотрудников от совместного использования или клиентов от загрузки и выгрузки файлов, вам не нужно полагаться на поиск в Интернете и попросить добровольцев на форумах и в социальных сетях для решения. У вас есть прямой доступ к нашим опытным инженерам, которые помогут вам отследить и устранить проблему.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "У вас есть контракт с поставщиком, предоставляющим конфиденциальную информацию о безопасности, смягчениям, исправлениям и обновлениям.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Если вы хотите пропустить выпуск или два и немного задержаться на текущей версии без сбоев, вам не нужно запускать программное обеспечение без обновлений безопасности. Мы предоставляем их вам до тех пор, пока это необходимо!",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Если у вас есть проблемы с производительностью и масштабируемостью, у вас есть лучший опыт под рукой, вместо того чтобы искать в Интернете и надеяться, что вы найдете решение.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Если вас спросят, как выполняется соответствие Nextcloud, и если вы можете осуществлять экспорт данных в соответствии с GDPR, HIPAA или другими правилами, у вас есть доступ к необходимой документации и вы можете использовать наш опыт для быстрого и точного реагирования.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Мы также можем предоставить вам интеграцию с Outlook, Online Office, масштабируемое и интегрированное аудио-видео и общение в чате, а другие функции доступны бесплатно только в очень ограниченной форме. И мы можем развивать дальнейшую интеграцию и возможности, которые вам нужны.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Подписка поможет вам получить максимальную отдачу от Nextcloud! Разве ваши пользователи не заслуживают лучшего?",
    "Learn more now" : "Узнать больше сейчас",
    "Your Nextcloud server Subscription is over limit" : "Ваша подписка на сервере Nextcloud превысила ограничение",
    "Dear admin," : "Дорогой администратор,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка Nextcloud не покрывает то количество пользователей, которые в настоящее время активны на этом сервере. Свяжитесь с менеджером аккаунта Nextcloud, чтобы обновить подписку!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "Ваш менеджер %1$s доступен по адресу электронной почты %2$s или номеру телефона %3$s.",
    "Thank you," : "Спасибо,",
    "Your Nextcloud team" : "Твоя команда Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Срок подписки на ваш сервер Nextcloud истек",
    "Your Nextcloud server Subscription is expired!" : "Срок подписки на ваш сервер Nextcloud истек!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка на Nextcloud истекла! Свяжитесь с аккаунт-менеджером Nextcloud, чтобы обновить подписку!",
    "Support" : "Поддержка",
    "Getting support and help for your Nextcloud" : "Получение поддержки и помощи для вашего Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Приложение поддержки предоставляет вам прямой доступ к техпомощи и консультационным ресурсам, специальным опциям для контакта с вашим менеджером учетных записей и обзор вашей корпоративной подписки.",
    "Basic subscription" : "Базовая подписка",
    "Standard subscription" : "Стандартная подписка",
    "Premium subscription" : "Премиум подписка",
    "Géant subscription" : "Гигантская подписка",
    "Silver partner subscription" : "Подписка серебряного партнера ",
    "Gold partner subscription" : "Подписка золотого партнера ",
    "Subscription" : "Подписка",
    "Over subscription limit" : "Превышено ограничение подписки",
    "Valid subscription" : "Действующая подписка",
    "Expired subscription" : "Истекшая подписка",
    "Subscription key:" : "Ключ подписки:",
    "_Expires in %n year_::_Expires in %n years_" : ["Истекает через год","Истекает через %n года","Истекает через %n лет","Истекает через %n года"],
    "_Expires in %n month_::_Expires in %n months_" : ["Истекает через месяц","Истекает через %n месяца","Истекает через  %n месяцев","Истекает через  %n месяца"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Истекает через неделю","Истекает через %n недели","Истекает через %n недель","Истекает через %n недели"],
    "_Expires in %n day_::_Expires in %n days_" : ["Истекает через день","Истекает через %n дня","Истекает через %n дней","Истекает через %n дня"],
    "_For %n users_::_For %n users_" : ["Для одного пользователя","Для %n пользователей","Для  %n пользователей","Для %n пользователей"],
    "_currently at %n user_::_currently at %n users_" : ["используется одним пользователем","используется %n пользователями","используется %n пользователями","используется %n пользователями"],
    "Includes support for %s" : "Включает поддержку %s",
    "Includes support for %1$s & %2$s" : "Включает поддержку %1$s и %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Включает поддержку %1$s, %2$s и %3$s",
    "Update subscription key" : "Обновить ключ подписки",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s является Вашим аккаунт менеджером. Не стесняйтесь обращаться к нам, если у вас есть вопросы относительно вашей подписки.",
    "Access Nextcloud portal" : "Доступ к порталу Nextcloud",
    "System information" : "Системная информация",
    "Generate system report" : "Сгенерировать системный отчет",
    "Enterprise subscription recommended" : "Рекомендуется корпоративная подписка",
    "No active enterprise subscription" : "Нет активной корпоративной подписки",
    "Unsupported" : "Не поддерживается",
    "This Nextcloud server has no Enterprise Subscription." : "Этот сервер Nextcloud не имеет корпоративной подписки.",
    "Advantages" : "Преимущества",
    "Get a quote" : "Получить квоту",
    "More information" : "Больше информации",
    "Subscription benefits" : "Преимущества подписки",
    "Pricing" : "Цены",
    "Commmunity support" : "Поддержка сообщества",
    "Forum" : "Форум",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud - бесплатное программное обеспечение, которое поддерживается очень активным сообществом. Пожалуйста, зарегистрируйтесь на форуме, чтобы задать вопросы и обсудить с другими.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud использует GitHub как платформу для совместной работы. Там Вы можете напрямую сообщать об ошибках.",
    "Chat" : "Чат",
    "Nextcloud forum" : "Nextcloud форум",
    "Nextcloud at GitHub" : "Nextcloud на GitHub",
    "Open chat" : "Открытый чат",
    "Subscription key" : "Ключ подписки",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Если у вас есть активная Подписка Nextcloud, пожалуйста, введите ваш ключ подписки здесь",
    "Learn more about an enterprise subscription." : "Узнайте больше о подписке предприятия",
    "Set subscription key" : "Установить ключ подписки",
    "The subscription key was invalid." : "Недопустимый ключ подписки.",
    "The subscription key had an invalid format." : "Ключ подписки в неверном формате",
    "News" : "Новости",
    "Follow us on Google+" : "Следите за нашими новостями в Google Plus",
    "Like our Facebook page" : "Посмотрите нашу страницу на Facebook",
    "Follow us on Twitter" : "Следите за нашими новостями в Twitter",
    "Check out our blog" : "Просмотрите наш блог",
    "Subscribe to our newsletter" : "Подписывайтесь на нашу новостную рассылку"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/ru.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Ссылка:",
    "Password:" : "Пароль:",
    "Generating system report failed." : "Не удалось создать системный отчёт.",
    "Subscription notifications" : "Уведомления о подписке",
    "Could not create folder \"System information\" to store generated report." : "Не удалось создать папку «System information» для сохранения отчёта.",
    "Could not create file \"%s\" to store generated report." : "Не удалось создать файл «%s» для сохранения отчёта.",
    "Could not share file \"%s\"." : "Не удалось предоставить общий доступ к файлу «%s».",
    "Nextcloud Subscription" : "Подписка Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "У вашего сервера нет подписки Nextcloud или ваша подписка истекла.",
    "Your Nextcloud server subscription does not cover your number of users." : "Ваша подписка Nextcloud не предназначена на количество пользователей вашего сервера.",
    "Your Nextcloud Subscription has expired!" : "Закончился срок действия подписки Nextcloud!",
    "Your server has no Nextcloud Subscription" : "У вашего сервера нет подписки Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Ваш сервер Nextcloud не поддерживается подпиской Nextcloud Enterprise.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Имея Enterprise подписку, вы можете быть на 100% уверены, что наши разработчики нацелены на безопасность, оснащенность, производительность и функциональность вашего облачного сервера!",
    "A subscription helps you get the most out of Nextcloud!" : "Откройте все возможности с подпиской Nextcloud!",
    "Learn more now" : "Узнайте больше сейчас",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %1$s, поскольку зарегистрировано больше %2$s пользователей.",
    "Your Nextcloud server Subscription is over limit" : "Ваша подписка на сервере Nextcloud превысила ограничение",
    "Dear admin," : "Дорогой администратор,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка Nextcloud не покрывает то количество пользователей, которые в настоящее время активны на этом сервере. Свяжитесь с менеджером аккаунта Nextcloud, чтобы обновить подписку!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "Ваш менеджер %1$s доступен по адресу электронной почты %2$s или номеру телефона %3$s.",
    "Thank you," : "Спасибо,",
    "Your Nextcloud team" : "Ваша команда Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %s, поскольку число зарегистрированных пользователей превысило число покрываемых подпиской.",
    "Your Nextcloud server Subscription is expired" : "Срок подписки на ваш сервер Nextcloud истек",
    "Your Nextcloud server Subscription is expired!" : "Срок подписки на ваш сервер Nextcloud истек!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "Ваша подписка на Nextcloud истекла! Свяжитесь с аккаунт-менеджером Nextcloud, чтобы обновить подписку!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Это сообщение было отправлено всем администраторам вашего облака  Nextcloud по адресу %s, поскольку ваша подписка истекла.",
    "Support" : "Поддержка",
    "Getting support and help for your Nextcloud" : "Получение поддержки и помощи для вашего Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Приложение поддержки предоставляет вам прямой доступ к техпомощи и консультационным ресурсам, специальным опциям для контакта с вашим менеджером учетных записей и обзор вашей корпоративной подписки.",
    "Basic subscription" : "Базовая подписка",
    "Standard subscription" : "Стандартная подписка",
    "Premium subscription" : "Премиум подписка",
    "Géant subscription" : "Гигантская подписка",
    "Silver partner subscription" : "Подписка серебряного партнера ",
    "Gold partner subscription" : "Подписка золотого партнера ",
    "Subscription" : "Подписка",
    "Over subscription limit" : "Превышено ограничение подписки",
    "Valid subscription" : "Действующая подписка",
    "Expired subscription" : "Истекшая подписка",
    "Subscription key:" : "Ключ подписки:",
    "_Expires in %n year_::_Expires in %n years_" : ["Истекает через год","Истекает через %n года","Истекает через %n лет","Истекает через %n года"],
    "_Expires in %n month_::_Expires in %n months_" : ["Истекает через месяц","Истекает через %n месяца","Истекает через  %n месяцев","Истекает через  %n месяца"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Истекает через неделю","Истекает через %n недели","Истекает через %n недель","Истекает через %n недели"],
    "_Expires in %n day_::_Expires in %n days_" : ["Истекает через день","Истекает через %n дня","Истекает через %n дней","Истекает через %n дня"],
    "_For %n users_::_For %n users_" : ["Для одного пользователя","Для %n пользователей","Для  %n пользователей","Для %n пользователей"],
    "_currently at %n user_::_currently at %n users_" : ["используется одним пользователем","используется %n пользователями","используется %n пользователями","используется %n пользователями"],
    "Includes support for %s" : "Включает поддержку %s",
    "Includes support for %1$s & %2$s" : "Включает поддержку %1$s и %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Включает поддержку %1$s, %2$s и %3$s",
    "Update subscription key" : "Обновить ключ подписки",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s является Вашим аккаунт менеджером. Не стесняйтесь обращаться к нам, если у вас есть вопросы относительно вашей подписки.",
    "Access Nextcloud portal" : "Доступ к порталу Nextcloud",
    "System information" : "Системная информация",
    "Generate system report" : "Сгенерировать системный отчет",
    "Enterprise subscription recommended" : "Мы рекомендуем Enterprise подписку",
    "No active enterprise subscription" : "Нет активной Enterprise подписки",
    "Unsupported" : "Не поддерживается",
    "This Nextcloud server has no Enterprise Subscription." : "Этот сервер Nextcloud не имеет Enterprise подписки.",
    "Advantages" : "Преимущества",
    "Get a quote" : "Получить квоту",
    "More information" : "Больше информации",
    "Subscription benefits" : "Преимущества подписки",
    "Pricing" : "Цены",
    "Commmunity support" : "Поддержка сообщества",
    "Forum" : "Форум",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud - бесплатное программное обеспечение, которое поддерживается очень активным сообществом. Пожалуйста, зарегистрируйтесь на форуме, чтобы задать вопросы и обсудить с другими.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud использует GitHub как платформу для совместной работы. Там Вы можете напрямую сообщать об ошибках.",
    "Chat" : "Чат",
    "Nextcloud forum" : "Nextcloud форум",
    "Nextcloud at GitHub" : "Nextcloud на GitHub",
    "Open chat" : "Открытый чат",
    "Subscription key" : "Ключ подписки",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "У вас есть подписка Nextcloud? Введите ваш ключ здесь.",
    "Learn more about an enterprise subscription." : "Узнайте больше о подписке Enterprise.",
    "Set subscription key" : "Установить ключ подписки",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Информация о подписке не была загружена. Дождитесь следующей попытки.",
    "The subscription key was invalid." : "Недопустимый ключ подписки.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Ключ подписки не может быть подтвержден, поскольку сервер не имеет доступ в интернет. Обратитесь в службу поддержки, чтобы решить эту проблему.",
    "The subscription key had an invalid format." : "Ключ подписки имеет неверный формат",
    "While fetching the subscription information an error happened." : "Ошибка при загрузке информации о подписке.",
    "News" : "Новости",
    "Follow us on Google+" : "Следите за нашими новостями в Google Plus",
    "Like our Facebook page" : "Посмотрите нашу страницу на Facebook",
    "Follow us on Twitter" : "Следите за нашими новостями в Twitter",
    "Check out our blog" : "Просмотрите наш блог",
    "Subscribe to our newsletter" : "Подписывайтесь на нашу новостную рассылку"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
